# src/hpmpy_project/__init__.py
"""hpmpy-project."""
from importlib.metadata import version

__version__ = version(__name__)
